﻿function Update-ELHCConfig
{
    [CmdletBinding(SupportsShouldProcess=$true, 
                  PositionalBinding=$false,
                  ConfirmImpact='Medium')]
    [Alias()]
    [OutputType([PSOBJECT])]

    param (
        [Parameter(Mandatory=$false, Position=0)]
        [string]$ConfigPath = (Get-InstalledModule -Name ELHealthCheck).installedlocation + "\ELHC.config"
    )
    
    #Placeholder function for updates to XML config file
    [xml]$Config = Get-Content $ConfigPath
    
    if ($Config.root.ComponentTimeout) {
        Write-Verbose "Config is up to date"
        return
    }

    #add the new ELStatistics node
    $StatsNode = $Config.CreateElement("component")
    $StatsNode.SetAttribute("Name","Get-ELStatistics")
    $Enabled = $Config.CreateElement("enabled")
    $Enabled.InnerText = "TRUE"
    $ELStats = $Config.CreateElement("ELStats")
    $StatsNode.AppendChild($Enabled)
    $StatsNode.AppendChild($ELStats)
    $Config.root.components.standalone.AppendChild($StatsNode)

    #add the new ComponentTimeout node and DepartmentPOC
    $TimeoutNode = $Config.CreateElement("ComponentTimeout")
    $TimeoutNode.InnerText = 300
    $Config.root.AppendChild($TimeoutNode)

    $DeptPOC = $Config.CreateElement("DepartmentPOC")
    $DeptPOC.InnerText = "Not specified"
    $Config.root.AppendChild($DeptPOC)

    #remove the alert on mempages
    $PerfNode = $Config.root.components.standalone.component | ? {$_.name -eq "Get-Performance"}
    $MemNode = $PerfNode.Performance.alerts.GetElementsByTagName("AlertMemPages")[0]
    $PerfNode.Performance.alerts.RemoveChild($MemNode)
        
    $Config.Save($ConfigPath)



}