﻿<#
    .Synopsis
    Short description
    .DESCRIPTION
    Long description
    .EXAMPLE
    Example of how to use this cmdlet
    .EXAMPLE
    Another example of how to use this cmdlet
    .INPUTS
    Inputs to this cmdlet (if any)
    .OUTPUTS
    Output from this cmdlet (if any)
    .NOTES
    General notes
    .COMPONENT
    The component this cmdlet belongs to
    .ROLE
    The role this cmdlet belongs to
    .FUNCTIONALITY
    The functionality that best describes this cmdlet
#>
function Get-DVRConfig
{
    [CmdletBinding(SupportsShouldProcess=$true, 
                  PositionalBinding=$false,
                  ConfirmImpact='Medium')]
    [Alias()]
    [OutputType([PSOBJECT])]
    
    param (
        [Parameter(Mandatory=$True, ParameterSetName='ELHC')]
        [ValidateNotNullOrEmpty()]
        [PSObject]$ELHCConfig = $false,

        [Parameter(Mandatory=$True, ParameterSetName='External')]
        [ValidateNotNullOrEmpty()]
        [string]$ConnectionString = "data source=(local);initial catalog=WGEvidenceLibrary;integrated security=true;connection lifetime=30;"
    )

    if($ELHCConfig) {
        $ConnectionString = $ELHCConfig.root.ConnectionString
    }

    $Return = [ordered]@{
        'LogType' = 'DVRConfig'
    }

    $ConfigTables = @(
        'dbo.DVRAudioPolicy',
        'dbo.DVRAutoStartStopTriggerPolicy',
        'dbo.DVRCamera',
        'dbo.DVRDelayPolicy',
        'dbo.DVRImportSetting',
        'dbo.DVROnScreenTextDisplayPolicy',
        'dbo.DepartmentConfiguration',
        'dbo.DVRPolicy',
        'dbo.PowerBehaviorPolicy',
        'dbo.RadarSpeedPolicy',
        'dbo.DVRVideoRecordingSetting')

    foreach ($Table in $ConfigTables) {
        $Query = "SELECT * FROM $Table"
        
        $TempTable = Get-QueryResult -connectionString $ConnectionString -query $Query

        foreach ($Cell in $TempTable[0].PSObject.Properties | ? {$_.Name -notin @("ID","RowError","RowState","Table","ItemArray","HasErrors")}) {
            $Return.Add($Cell.Name, $Cell.Value)
        }
    }

    return $Return
}