﻿<#
    .Synopsis
    Short description
    .DESCRIPTION
    Long description
    .EXAMPLE
    Example of how to use this cmdlet
    .EXAMPLE
    Another example of how to use this cmdlet
    .INPUTS
    Inputs to this cmdlet (if any)
    .OUTPUTS
    Output from this cmdlet (if any)
    .NOTES
    General notes
    .COMPONENT
    The component this cmdlet belongs to
    .ROLE
    The role this cmdlet belongs to
    .FUNCTIONALITY
    The functionality that best describes this cmdlet
#>
function Get-ELStatistics
{
    [CmdletBinding(SupportsShouldProcess=$true, 
                  PositionalBinding=$false,
                  ConfirmImpact='Medium')]
    [Alias()]
    [OutputType([PSOBJECT])]
    
    param (
        [Parameter(Mandatory=$True, ParameterSetName='ELHC')]
        [ValidateNotNullOrEmpty()]
        [PSObject]$ELHCConfig = $false,

        [Parameter(Mandatory=$True, ParameterSetName='External')]
        [ValidateNotNullOrEmpty()]
        [string]$ConnectionString = "data source=(local);initial catalog=WGEvidenceLibrary;integrated security=true;connection lifetime=30;"
    )

    if($ELHCConfig) {
        $ConnectionString = $ELHCConfig.root.ConnectionString
    }

    $Return = [ordered]@{
        'LogType' = 'ELStatistics'
    }

    $EventLengthQuery = "
        declare
	        @minLength int,
	        @maxLength int,
	        @num bigint = 0,
	        @beancounter int = 0,
	        @steps int = 11,
	        @tempstring varchar(255)

        declare	@tempTable TABLE
	        (Bucket varchar(255), [Count] bigint, step int)
        declare @referenceTable TABLE
	        (BucketName varchar(255), lowerbound int, upperbound int, bean int)

        insert into @referenceTable VALUES ('LEN-S(0-10)', 0, 9, 0)
        insert into @referenceTable VALUES ('LEN-S(11-30)', 10, 29, 1)
        insert into @referenceTable VALUES ('LEN-S(31-60)', 30, 59, 2)
        insert into @referenceTable VALUES ('LEN-M(1-2)', 60, 119, 3)
        insert into @referenceTable VALUES ('LEN-M(2-5)', 120, 299, 4)
        insert into @referenceTable VALUES ('LEN-M(5-15)', 300, 899, 5)
        insert into @referenceTable VALUES ('LEN-M(15-30)', 900, 1799, 6)
        insert into @referenceTable VALUES ('LEN-M(30-60)', 1800, 3599, 7)
        insert into @referenceTable VALUES ('LEN-H(1-2)', 3600, 7199, 8)
        insert into @referenceTable VALUES ('LEN-H(2-4)', 7200, 14399, 9)
        insert into @referenceTable VALUES ('LEN-H(4+)', 14400, 10000000, 10)

        while @beancounter < @steps
        begin
	        select @minLength = lowerbound
	        from @referenceTable r
	        where bean = @beancounter

	        select @maxLength = upperbound
	        from @referenceTable r
	        where bean = @beancounter

	        select @tempstring = Bucketname
	        from @referenceTable r
	        where bean = @beancounter
	
	        select @num = count(*)
	        from dbo.RecordingEvent re
	        where re.Duration/1e7 between @minLength and @maxLength

	        insert into @tempTable VALUES (@tempstring, @num, @beancounter)

	        set @beancounter += 1
        end;

        select Bucket, [COUNT] from @tempTable order by step"

    $EventLength = Get-QueryResult -query $EventLengthQuery -connectionString $ConnectionString

    foreach ($line in $EventLength) {
        $Return.Add($line.Bucket, $line.COUNT)
    }

    $EventSizeQuery = "
        declare
	        @minSize int,
	        @maxSize int,
	        @num bigint = 0,
	        @beancounter int = 0,
	        @steps int = 10,
	        @tempstring varchar(255)

        declare	@tempTable TABLE
	        (Bucket varchar(255), [Count] bigint, step int)
        declare @referenceTable TABLE
	        (BucketName varchar(255), lowerbound int, upperbound int, bean int)

        insert into @referenceTable VALUES ('SIZE_MB(0-99)', 0, 99, 0)
        insert into @referenceTable VALUES ('SIZE_MB(100-249)', 100, 249, 1)
        insert into @referenceTable VALUES ('SIZE_MB(250-499)', 250, 499, 2)
        insert into @referenceTable VALUES ('SIZE_MB(500-999)', 500, 999, 3)
        insert into @referenceTable VALUES ('SIZE_GB(1-2)', 1000, 1999, 4)
        insert into @referenceTable VALUES ('SIZE_GB(2-5)', 2000, 4999, 5)
        insert into @referenceTable VALUES ('SIZE_GB(5-10)', 5000, 9999, 6)
        insert into @referenceTable VALUES ('SIZE_GB(10-15)', 10000, 14999, 7)
        insert into @referenceTable VALUES ('SIZE_GB(15-20)', 15000, 19999, 8)
        insert into @referenceTable VALUES ('SIZE_GB(20+)', 20000, 2000000, 9)

        while @beancounter < @steps
        begin
	        select @minSize = lowerbound
	        from @referenceTable r
	        where bean = @beancounter

	        select @maxSize = upperbound
	        from @referenceTable r
	        where bean = @beancounter

	        select @tempstring = Bucketname
	        from @referenceTable r
	        where bean = @beancounter
	
	        select @num = count(distinct re.ID)
	        from dbo.RecordingEvent re
	        join dbo.RecordingEventStream res
	        on re.ID = res.RecordEventID
	        where res.Size/1024/1024 between @minSize and @maxSize

	        insert into @tempTable VALUES (@tempstring, @num, @beancounter)

	        set @beancounter += 1
        end;
        select Bucket, [COUNT] from @tempTable order by step"

    $EventSize = Get-QueryResult -query $EventSizeQuery -connectionString $ConnectionString

    foreach ($line in $EventSize) {
        $Return.Add($line.Bucket, $line.COUNT)
    }


    return $Return
}